<?php
/**
 * @copyright: Copyright © 2021 Firebear Studio. All rights reserved.
 * @author   : Firebear Studio <fbeardev@gmail.com>
 */
namespace Firebear\PlatformSap\Model\Import\Source;

use Firebear\PlatformSap\Model\Import\Source\Gateway\ProductPriceAndStock as ProductPriceGateway;
use Magento\Framework\App\RequestInterface;

/**
 * Sap product price source
 */
class ProductSpecialPrice extends AbstractSource
{
    /**
     * @var \Firebear\PlatformSap\Model\Source\Gateway\Product
     */
    protected $gateway;

    /**
     * Config data
     *
     * @var array
     */
    protected $_data = [];

    /**
     * @var \Magento\Framework\App\RequestInterface
     */
    protected $request;

    /**
     * ProductPrice constructor.
     * @param ProductPriceGateway $gateway
     * @param RequestInterface $request
     * @param null $data
     * @throws \Exception
     */
    public function __construct(
        ProductPriceGateway $gateway,
        RequestInterface $request,
        $data = null
    ) {
        $this->gateway = $gateway;
        $this->request = $request;
        $this->parseEntities($data);
    }

    /**
     * @param $data
     * @return array|bool
     * @throws \Exception
     */
    protected function parseEntities($data)
    {
        $result = [];
        $this->entities = parent::parseEntities($data);
        if (!empty($this->entities)) {
            foreach ($this->entities as $key => $entity) {
                if (isset($entity['ItemCode'])) {
                    $result[$key]['sku'] = $entity['ItemCode'];
                }
                if (isset($entity['Price'])) {
                    $result[$key]['special_price'] = $entity['Price'];
                }
            }
        }
        $this->entities = $result;
        $this->_colNames = array_keys($this->entities[0] ?? []);
        return $this->entities;
    }
}
