<?php
/**
 * @copyright: Copyright © 2020 Firebear Studio GmbH. All rights reserved.
 */

namespace Firebear\PlatformSap\Observer;

use Magento\Framework\Event\ObserverInterface;
use Magento\Framework\Event\Observer as EventObserver;
use Firebear\PlatformSap\Model\Order\UpdatePublisher;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Psr\Log\LoggerInterface;

class CheckoutSubmitAllAfterObserver implements ObserverInterface
{
    /**
     * @var UpdatePublisher
     */
    private $orderUpdatePublisher;

    /**
     * @var ScopeConfigInterface
     */
    private $scopeConfig;

    /**
     * @var LoggerInterface
     */
    private $logger;

    /**
     * CheckoutSubmitAllAfterObserver constructor.
     * @param UpdatePublisher $orderUpdatePublisher
     * @param ScopeConfigInterface $scopeConfig
     * @param LoggerInterface $logger
     */
    public function __construct(
        UpdatePublisher $orderUpdatePublisher,
        ScopeConfigInterface $scopeConfig,
        LoggerInterface $logger
    ) {
        $this->orderUpdatePublisher = $orderUpdatePublisher;
        $this->scopeConfig = $scopeConfig;
        $this->logger = $logger;
    }

    public function execute(EventObserver $observer)
    {
        if ($this->scopeConfig->getValue('firebear_importexport/sap/sap_export_orders')) {
            try {
                $order = $observer->getEvent()->getOrder();
                if ($order) {
                    $orderId = $order->getEntityId();
                    if (!empty($orderId)) {
                        $this->orderUpdatePublisher->execute($orderId);
                    }
                }
                $orders = $observer->getEvent()->getOrders();
                if ($orders) {
                    foreach ($orders as $order) {
                        $orderId = $order->getEntityId();
                        if (!empty($orderId)) {
                            $this->orderUpdatePublisher->execute($orderId);
                        }
                    }
                }
            } catch (\Exception $e) {
                $this->logger->critical($e);
            }
        }
    }
}
